@@ -2,9 +2,9 @@ package RDF::iCalendar::Entity;
 
 use 5.008;
 use base qw[RDF::vCard::Entity];
-use common::sense;
+use strict;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 1;
 
